/// <reference types="node" />
/// <reference types="node" />
import * as fs from 'fs';
import gm from 'gm';
import { CkValue, CkType } from '@ckstack/ck-lib';
declare class CkFileUtils {
    /**
     * log object 를 초기화 한다.
     * @deprecated 2022.11.24 일 부터 더 이상 사용 하지 않는다.
     */
    static init(): void;
    /**
     * 이미지를 crop 으로 resize 한다.
     * @param src
     * @param dest
     * @param width
     * @param height
     * @param x
     * @param y
     * @param reqIpAndLhdAndHttpInfo
     * @param lang
     * @private
     */
    private static __crop;
    /**
     * 이미지를 resize 한다.
     * @param src
     * @param dest
     * @param width
     * @param height
     * @param isForceSize
     * @param reqIpAndLhdAndHttpInfo
     * @param lang
     * @private
     */
    private static __resize;
    /**
     * async 로 파일을 read 하여 버프를 리턴 한다.
     * 정상으로 처리 되면 Promise<Buffer> 를 리턴 하고, 읽기 실패하면 error 를 throw 하거나 null 을 리턴 한다.
     *
     * @param reqIpAndLhdAndHttpInfo 로그키
     * @param filePath 파일의 절대 경로
     * @param lang 언어 코드. 에러 로그 처리시 사용 됨. 없어도 무방.
     * @throws CkError
     */
    static readAsyncFileToBuffer(reqIpAndLhdAndHttpInfo: string, filePath: string, lang?: CkValue.SUPPORT_LANG): Promise<Buffer> | null;
    /**
     * Buffer 에 저장된 파일 데이터를 물리 파일로 저장 한다. 파일 저장을 실패 하면 error 를 throw 한다.
     *
     * @param reqIpAndLhdAndHttpInfo
     * @param srcBuffer
     * @param destFilePath
     * @param opt
     * @param lang
     * @throws CkError
     */
    static writeAsyncBufferToFile(reqIpAndLhdAndHttpInfo: string, srcBuffer: Buffer, destFilePath: string, opt?: fs.WriteFileOptions, lang?: CkValue.SUPPORT_LANG): void;
    /**
     * Create a directory. It creates all the top to bottom along the path.
     * 디렉토리가 이미지 존재하더라도 에러 발생하지 않는다.
     *
     * @param dir 디렉토리명. (/a/b/c/d 형태로 준다면 a, b, c, d 디렉토리를 모두 만든다.)
     * @param reqIpAndLhdAndHttpInfo 로그 헤더
     */
    static mkdirs(dir: string, reqIpAndLhdAndHttpInfo?: string): void;
    /**
     * Delete the file or directory. not empty 인 디렉토리도 삭제 가능함.
     * 존재하지 않는 파일/디렉토리를 삭제 시도 하더라도 에러 발생하지 않음.
     *
     * @param filePath 삭제할 파일 패스나 디렉토리 패스
     * @param reqIpAndLhdAndHttpInfo 로그 헤더
     * @param lang 에러 발생시 사용할 언어 코드
     */
    static removeFileOrDirectory(filePath: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): void;
    /**
     * Copy the file. Both src and dest must contain file names.
     * dest 에 파일이 존재하면 overwrite 함.
     *
     * @param src 복사할 source 파일
     * @param dest 복사될 dest 위치
     * @param reqIpAndLhdAndHttpInfo 로그 헤더
     * @param lang 에러 발생시 사용할 언어 코드
     */
    static copy(src: string, dest: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): Promise<string>;
    /**
     * Get the file size. Returns a number in byte unit.
     * 파일이 존재하지 않으면 error 를 throw 함.
     *
     * @param filePath
     * @param reqIpAndLhdAndHttpInfo
     * @param lang
     * @throws CkError
     */
    static getFileSize(filePath: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): number;
    /**
     * Get the image file size (resolution, width x height).
     * 본 함수가 정상 동작하려면, 동작하는 서버에 gm 이 설치 되어야 한다.
     * 파일이 존재하지 않으면 error 를 throw 한다.
     *
     * @param filePath resolution 을 구할 이미지 파일의 경로
     * @param reqIpAndLhdAndHttpInfo 로그 헤더
     * @param lang 에러 발생시 사용할 언어 코드
     */
    static getImageFileResolution(filePath: string, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): Promise<gm.Dimensions>;
    /**
     * 함수 호출하는 곳에서 try, catch 로 예외 상황 처리 해야 함.
     * src 파일이 존재하지 않으면 에러 발생.
     * dest 파일이 존재하면, overwrite 함.
     * Resize the original image file and create a new resized file.
     *
     * mode : The following values are available.
     *  - crop : Cut to the desired size. Unconditional cropping
     *           results in areas that are not cropped and visible.
     *  - resize : Convert the size of the original file.
     *             The image is visible, but may be distorted.
     *
     * opt : Option to resize. Depends on crop and resize
     *  - When crop is the next item
     *      + x : origin x to crop
     *      + y : origin y to crop
     *      + w : width to crop
     *      + h : height to crop
     *  - the next item when resize
     *      + w : resize width
     *      + h : resize height
     *      + r : true or false. If false, resize it to the size you want.
     *            The image may be distorted.
     *            raito is forced to true if there is only w.
     *            If h is present, then ratio is forced to true.
     *
     * @param src 리사이즈를 할 이미지 원본 파일의 경로
     * @param dest 리사이즈 되어 저장될 이미지의 대상 경로
     * @param mode 리사이즈 할 방법. CkValue.IMAGE_RESIZE_MODE 항목을 지원 한다.
     * @param opt 리사이즈 옵션. CkType.IImageResizeOption 항목을 지원 한다.
     * @param reqIpAndLhdAndHttpInfo 로그 헤더
     * @param lang 에러 발생시 사용할 언어 코드
     */
    static resizeImage(src: string, dest: string, mode: CkValue.IMAGE_RESIZE_MODE, opt: CkType.IImageResizeOption, reqIpAndLhdAndHttpInfo?: string, lang?: CkValue.SUPPORT_LANG): Promise<string>;
}
export default CkFileUtils;
